##  Step 4: Connect SAP LeanIX to Microsoft Entra ID
  1. In the administration area of SAP LeanIX, navigate to Integrations.
  2. Choose Add Integrations.
  3. Under AI Agent Discovery, find Microsoft Entra ID and choose Configure.
  4. Enter a name for the integration.
  5. Enter the credentials copied from the Azure admin portal into the corresponding fields.
![Form to enter Microsoft Entra ID credentials in SAP LeanIX integration setup.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio7b1fb875f32c4a46a14104c1e00d771a_LowRes.png)
Entering Credentials in SAP LeanIX Configuration
  6. Choose Finish.
